# Flasik


---

## Directory Structure

```

    #ROOT
    |
    |-- __flasik__.py
    |
    |-- __config__.py
    |
    |-- Procfile
    |
    |-- requirements.txt
    |
    |-- /$application
        |
        |-- __init__.py
        |
        |-- __models__.py
        |
        |-- __views__.py
        |
        |-- cli.py
        |
        |-- templates
            |-- Index/
                |-- index.html
        |
        |-- static
            |-- images
            |-- css
            |-- js
            |-- assets.yml

```

## Serve your app

```
flasik-admin run
```

**__flasik__.py**

**__config__.py**

**$application**

**$application/__views__.py**

**$application/__models__.py**

**$application/templates**

**$application/static**
